# atkins

[![PyPI - Version](https://img.shields.io/pypi/v/atkins.svg)](https://pypi.org/project/atkins)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/atkins.svg)](https://pypi.org/project/atkins)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install atkins
```

## License

`atkins` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
